@@ -1,4 +1,4 @@
-# This code is part of Perl distribution Mail-Box-POP3 version 4.000.
+# This code is part of Perl distribution Mail-Box-POP3 version 4.01.
 # The POD got stripped from this file by OODoc version 3.05.
 # For contributors see file ChangeLog.
 
@@ -10,7 +10,7 @@
 
 
 package Mail::Box::POP3;{
-our $VERSION = '4.000';
+our $VERSION = '4.01';
 }
 
 use parent 'Mail::Box::Net';
@@ -18,7 +18,7 @@ use parent 'Mail::Box::Net';
 use strict;
 use warnings;
 
-use Log::Report  'mail-box-pop3';
+use Log::Report  'mail-box-pop3', import => [ qw/__x error trace warning/ ];
 
 use Mail::Box::POP3::Message ();
 use Mail::Box::Parser::Perl  ();
@@ -58,7 +58,7 @@ sub foundIn(@)
 sub addMessage($)
 {	my ($self, $message) = @_;
 
-	$self->log(ERROR => "You cannot write a message to a pop server (yet)")
+	error __x"you cannot write a message to a pop server (yet)"
 		if defined $message;
 
 	undef;
@@ -69,7 +69,7 @@ sub addMessages(@)
 {	my $self = shift;
 
 	# error message described in addMessage()
-	$self->log(ERROR => "You cannot write messages to a pop server (yet)")
+	error __x"you cannot write messages to a pop server (yet)"
 		if @_;
 
 	();
@@ -91,7 +91,7 @@ sub close(@)
 
 sub delete(@)
 {	my $self = shift;
-	$self->log(WARNING => "POP3 folders cannot be deleted.");
+	warning __x"POP3 folders cannot be deleted.";
 	undef;
 }
 
@@ -125,10 +125,8 @@ sub popClient(%)
 		authenticate => $self->{MBP_auth},
 		use_ssl      => $args{use_ssl} || $self->{MBP_use_ssl},
 		ssl_options  => $args{ssl_options} || $self->{MBP_ssl_opts}
-	);
-
-	$self->log(ERROR => "Cannot create POP3 client for $self.")
-		unless defined $client;
+	)
+		or error __x"cannot create POP3 client for {name}.", name => $self->name;
 
 	$self->{MBP_client} = $client;
 }
@@ -137,18 +135,17 @@ sub readMessages(@)
 {	my ($self, %args) = @_;
 
 	my $pop   = $self->popClient or return;
-	my @log   = $self->logSettings;
 	my $seqnr = 0;
 
 	foreach my $id ($pop->ids)
 	{	my $message = $args{message_type}->new(
-			head      => $args{head_delayed_type}->new(@log),
+			head      => $args{head_delayed_type}->new,
 			unique    => $id,
 			folder    => $self,
 			seqnr     => $seqnr++
 		);
 
-		my $body = $args{body_delayed_type}->new(@log, message => $message);
+		my $body = $args{body_delayed_type}->new(message => $message);
 		$message->storeBody($body);
 		$self->storeMessage($message);
 	}
@@ -166,7 +163,7 @@ sub getHead($)
 
 	unless(defined $lines)
 	{	$lines = [];
-		$self->log(WARNING  => "Message $uidl disappeared from POP3 server $self.");
+		warning __x"message {id} disappeared from POP3 server {name}.", id => $uidl, name => $self->name;
 	}
 
 	my $text   = join '', @$lines;
@@ -183,7 +180,7 @@ sub getHead($)
 
 	$self->lazyPermitted(0);
 
-	$self->log(PROGRESS => "Loaded head of $uidl.");
+	trace "Loaded head of $uidl.";
 	$head;
 }
 
@@ -197,7 +194,7 @@ sub getHeadAndBody($)
 
 	unless(defined $lines)
 	{	$lines = [];
-		$self->log(WARNING  => "Message $uidl disappeared from POP3 server $self.");
+		warning __x"message {id} disappeared from POP3 server {name}.", id => $uidl, name => $self->name;
 	}
 
 	my $parser = Mail::Box::Parser::Perl->new(   # not parseable by C parser
@@ -207,21 +204,21 @@ sub getHeadAndBody($)
 
 	my $head = $message->readHead($parser);
 	unless(defined $head)
-	{	$self->log(ERROR => "Cannot find head back for $uidl on POP3 server $self.");
+	{	error __x"cannot find head back for {id} on POP3 server {name}.", id => $uidl, name => $self->name;
 		$parser->stop;
 		return undef;
 	}
 
 	my $body = $message->readBody($parser, $head);
 	unless(defined $body)
-	{	$self->log(ERROR => "Cannot read body for $uidl on POP3 server $self.");
+	{	error __x"cannot read body for {id} on POP3 server {name}.", id => $uidl, name => $self->name;
 		$parser->stop;
 		return undef;
 	}
 
 	$parser->stop;
 
-	$self->log(PROGRESS => "Loaded message $uidl.");
+	trace "Loaded message $uidl.";
 	($head, $body);
 }
 
@@ -230,7 +227,7 @@ sub writeMessages($@)
 {	my ($self, $args) = @_;
 
 	if(my $modifications = grep $_->isModified, @{$args->{messages}})
-	{	$self->log(WARNING => "Update of $modifications messages ignored for POP3 folder $self.");
+	{	warning __x"update of {count} messages ignored for POP3 folder {name}.", count => $modifications, name => $self->name;
 	}
 
 	$self;
